<a id="mypy-boto3-proton"></a>

# mypy-boto3-proton

[![PyPI - mypy-boto3-proton](https://img.shields.io/pypi/v/mypy-boto3-proton.svg?color=blue)](https://pypi.org/project/mypy-boto3-proton)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-proton.svg?color=blue)](https://pypi.org/project/mypy-boto3-proton)
[![Docs](https://img.shields.io/readthedocs/boto3-stubs.svg?color=blue)](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mypy-boto3-proton?color=blue)](https://pypistats.org/packages/mypy-boto3-proton)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.Proton 1.27.0](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.14.5](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-proton docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-proton](#mypy-boto3-proton)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `Proton`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `boto3-stubs` for `Proton` service.

```bash
# install with boto3 type annotations
python -m pip install 'boto3-stubs[proton]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'boto3-stubs-lite[proton]'


# standalone installation
python -m pip install mypy-boto3-proton
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y mypy-boto3-proton
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto3-stubs[proton]` in your environment:

```bash
python -m pip install 'boto3-stubs[proton]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `boto3-stubs-lite[proton]` in your environment:

```bash
python -m pip install 'boto3-stubs-lite[proton]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `boto3-stubs` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `boto3-stubs` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[proton]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed `boto3-stubs`

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `boto3-stubs[proton]` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[proton]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto3-stubs[proton]` in your environment:

```bash
python -m pip install 'boto3-stubs[proton]'`
```

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `boto3-stubs[proton]` in your environment:

```bash
python -m pip install 'boto3-stubs[proton]'
```

Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ProtonClient` provides annotations for `boto3.client("proton")`.

```python
from boto3.session import Session

from mypy_boto3_proton import ProtonClient

client: ProtonClient = Session().client("proton")

# now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_proton.paginator` module contains type annotations for all
paginators.

```python
from boto3.session import Session

from mypy_boto3_proton import ProtonClient
from mypy_boto3_proton.paginator import (
    ListComponentOutputsPaginator,
    ListComponentProvisionedResourcesPaginator,
    ListComponentsPaginator,
    ListEnvironmentAccountConnectionsPaginator,
    ListEnvironmentOutputsPaginator,
    ListEnvironmentProvisionedResourcesPaginator,
    ListEnvironmentTemplateVersionsPaginator,
    ListEnvironmentTemplatesPaginator,
    ListEnvironmentsPaginator,
    ListRepositoriesPaginator,
    ListRepositorySyncDefinitionsPaginator,
    ListServiceInstanceOutputsPaginator,
    ListServiceInstanceProvisionedResourcesPaginator,
    ListServiceInstancesPaginator,
    ListServicePipelineOutputsPaginator,
    ListServicePipelineProvisionedResourcesPaginator,
    ListServiceTemplateVersionsPaginator,
    ListServiceTemplatesPaginator,
    ListServicesPaginator,
    ListTagsForResourcePaginator,
)

client: ProtonClient = Session().client("proton")

# Explicit type annotations are optional here
# Types should be correctly discovered by mypy and IDEs
list_component_outputs_paginator: ListComponentOutputsPaginator = client.get_paginator(
    "list_component_outputs"
)
list_component_provisioned_resources_paginator: ListComponentProvisionedResourcesPaginator = (
    client.get_paginator("list_component_provisioned_resources")
)
list_components_paginator: ListComponentsPaginator = client.get_paginator("list_components")
list_environment_account_connections_paginator: ListEnvironmentAccountConnectionsPaginator = (
    client.get_paginator("list_environment_account_connections")
)
list_environment_outputs_paginator: ListEnvironmentOutputsPaginator = client.get_paginator(
    "list_environment_outputs"
)
list_environment_provisioned_resources_paginator: ListEnvironmentProvisionedResourcesPaginator = (
    client.get_paginator("list_environment_provisioned_resources")
)
list_environment_template_versions_paginator: ListEnvironmentTemplateVersionsPaginator = (
    client.get_paginator("list_environment_template_versions")
)
list_environment_templates_paginator: ListEnvironmentTemplatesPaginator = client.get_paginator(
    "list_environment_templates"
)
list_environments_paginator: ListEnvironmentsPaginator = client.get_paginator("list_environments")
list_repositories_paginator: ListRepositoriesPaginator = client.get_paginator("list_repositories")
list_repository_sync_definitions_paginator: ListRepositorySyncDefinitionsPaginator = (
    client.get_paginator("list_repository_sync_definitions")
)
list_service_instance_outputs_paginator: ListServiceInstanceOutputsPaginator = client.get_paginator(
    "list_service_instance_outputs"
)
list_service_instance_provisioned_resources_paginator: ListServiceInstanceProvisionedResourcesPaginator = client.get_paginator(
    "list_service_instance_provisioned_resources"
)
list_service_instances_paginator: ListServiceInstancesPaginator = client.get_paginator(
    "list_service_instances"
)
list_service_pipeline_outputs_paginator: ListServicePipelineOutputsPaginator = client.get_paginator(
    "list_service_pipeline_outputs"
)
list_service_pipeline_provisioned_resources_paginator: ListServicePipelineProvisionedResourcesPaginator = client.get_paginator(
    "list_service_pipeline_provisioned_resources"
)
list_service_template_versions_paginator: ListServiceTemplateVersionsPaginator = (
    client.get_paginator("list_service_template_versions")
)
list_service_templates_paginator: ListServiceTemplatesPaginator = client.get_paginator(
    "list_service_templates"
)
list_services_paginator: ListServicesPaginator = client.get_paginator("list_services")
list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator(
    "list_tags_for_resource"
)
```

<a id="waiters-annotations"></a>

### Waiters annotations

`mypy_boto3_proton.waiter` module contains type annotations for all waiters.

```python
from boto3.session import Session

from mypy_boto3_proton import ProtonClient
from mypy_boto3_proton.waiter import (
    ComponentDeletedWaiter,
    ComponentDeployedWaiter,
    EnvironmentDeployedWaiter,
    EnvironmentTemplateVersionRegisteredWaiter,
    ServiceCreatedWaiter,
    ServiceDeletedWaiter,
    ServiceInstanceDeployedWaiter,
    ServicePipelineDeployedWaiter,
    ServiceTemplateVersionRegisteredWaiter,
    ServiceUpdatedWaiter,
)

client: ProtonClient = Session().client("proton")

# Explicit type annotations are optional here
# Types should be correctly discovered by mypy and IDEs
component_deleted_waiter: ComponentDeletedWaiter = client.get_waiter("component_deleted")
component_deployed_waiter: ComponentDeployedWaiter = client.get_waiter("component_deployed")
environment_deployed_waiter: EnvironmentDeployedWaiter = client.get_waiter("environment_deployed")
environment_template_version_registered_waiter: EnvironmentTemplateVersionRegisteredWaiter = (
    client.get_waiter("environment_template_version_registered")
)
service_created_waiter: ServiceCreatedWaiter = client.get_waiter("service_created")
service_deleted_waiter: ServiceDeletedWaiter = client.get_waiter("service_deleted")
service_instance_deployed_waiter: ServiceInstanceDeployedWaiter = client.get_waiter(
    "service_instance_deployed"
)
service_pipeline_deployed_waiter: ServicePipelineDeployedWaiter = client.get_waiter(
    "service_pipeline_deployed"
)
service_template_version_registered_waiter: ServiceTemplateVersionRegisteredWaiter = (
    client.get_waiter("service_template_version_registered")
)
service_updated_waiter: ServiceUpdatedWaiter = client.get_waiter("service_updated")
```

<a id="literals"></a>

### Literals

`mypy_boto3_proton.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_proton.literals import (
    BlockerStatusType,
    BlockerTypeType,
    ComponentDeletedWaiterName,
    ComponentDeployedWaiterName,
    ComponentDeploymentUpdateTypeType,
    DeploymentStatusType,
    DeploymentUpdateTypeType,
    EnvironmentAccountConnectionRequesterAccountTypeType,
    EnvironmentAccountConnectionStatusType,
    EnvironmentDeployedWaiterName,
    EnvironmentTemplateVersionRegisteredWaiterName,
    ListComponentOutputsPaginatorName,
    ListComponentProvisionedResourcesPaginatorName,
    ListComponentsPaginatorName,
    ListEnvironmentAccountConnectionsPaginatorName,
    ListEnvironmentOutputsPaginatorName,
    ListEnvironmentProvisionedResourcesPaginatorName,
    ListEnvironmentTemplateVersionsPaginatorName,
    ListEnvironmentTemplatesPaginatorName,
    ListEnvironmentsPaginatorName,
    ListRepositoriesPaginatorName,
    ListRepositorySyncDefinitionsPaginatorName,
    ListServiceInstanceOutputsPaginatorName,
    ListServiceInstanceProvisionedResourcesPaginatorName,
    ListServiceInstancesFilterByType,
    ListServiceInstancesPaginatorName,
    ListServiceInstancesSortByType,
    ListServicePipelineOutputsPaginatorName,
    ListServicePipelineProvisionedResourcesPaginatorName,
    ListServiceTemplateVersionsPaginatorName,
    ListServiceTemplatesPaginatorName,
    ListServicesPaginatorName,
    ListTagsForResourcePaginatorName,
    ProvisionedResourceEngineType,
    ProvisioningType,
    RepositoryProviderType,
    RepositorySyncStatusType,
    ResourceDeploymentStatusType,
    ResourceSyncStatusType,
    ServiceCreatedWaiterName,
    ServiceDeletedWaiterName,
    ServiceInstanceDeployedWaiterName,
    ServicePipelineDeployedWaiterName,
    ServiceStatusType,
    ServiceTemplateSupportedComponentSourceTypeType,
    ServiceTemplateVersionRegisteredWaiterName,
    ServiceUpdatedWaiterName,
    SortOrderType,
    SyncTypeType,
    TemplateTypeType,
    TemplateVersionStatusType,
    ProtonServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    WaiterName,
    RegionName,
)


def check_value(value: BlockerStatusType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_proton.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_proton.type_defs import (
    AcceptEnvironmentAccountConnectionInputRequestTypeDef,
    EnvironmentAccountConnectionTypeDef,
    RepositoryBranchTypeDef,
    CancelComponentDeploymentInputRequestTypeDef,
    ComponentTypeDef,
    CancelEnvironmentDeploymentInputRequestTypeDef,
    CancelServiceInstanceDeploymentInputRequestTypeDef,
    ServiceInstanceTypeDef,
    CancelServicePipelineDeploymentInputRequestTypeDef,
    ServicePipelineTypeDef,
    CompatibleEnvironmentTemplateInputTypeDef,
    CompatibleEnvironmentTemplateTypeDef,
    ComponentSummaryTypeDef,
    ResourceCountsSummaryTypeDef,
    TagTypeDef,
    RepositoryBranchInputTypeDef,
    EnvironmentTemplateTypeDef,
    EnvironmentTemplateVersionTypeDef,
    RepositoryTypeDef,
    CreateServiceSyncConfigInputRequestTypeDef,
    ServiceSyncConfigTypeDef,
    ServiceTemplateTypeDef,
    CreateTemplateSyncConfigInputRequestTypeDef,
    TemplateSyncConfigTypeDef,
    DeleteComponentInputRequestTypeDef,
    DeleteEnvironmentAccountConnectionInputRequestTypeDef,
    DeleteEnvironmentInputRequestTypeDef,
    DeleteEnvironmentTemplateInputRequestTypeDef,
    DeleteEnvironmentTemplateVersionInputRequestTypeDef,
    DeleteRepositoryInputRequestTypeDef,
    DeleteServiceInputRequestTypeDef,
    DeleteServiceSyncConfigInputRequestTypeDef,
    DeleteServiceTemplateInputRequestTypeDef,
    DeleteServiceTemplateVersionInputRequestTypeDef,
    DeleteTemplateSyncConfigInputRequestTypeDef,
    EnvironmentAccountConnectionSummaryTypeDef,
    EnvironmentSummaryTypeDef,
    EnvironmentTemplateFilterTypeDef,
    EnvironmentTemplateSummaryTypeDef,
    EnvironmentTemplateVersionSummaryTypeDef,
    WaiterConfigTypeDef,
    GetComponentInputRequestTypeDef,
    GetEnvironmentAccountConnectionInputRequestTypeDef,
    GetEnvironmentInputRequestTypeDef,
    GetEnvironmentTemplateInputRequestTypeDef,
    GetEnvironmentTemplateVersionInputRequestTypeDef,
    GetRepositoryInputRequestTypeDef,
    GetRepositorySyncStatusInputRequestTypeDef,
    GetServiceInputRequestTypeDef,
    GetServiceInstanceInputRequestTypeDef,
    GetServiceInstanceSyncStatusInputRequestTypeDef,
    RevisionTypeDef,
    GetServiceSyncBlockerSummaryInputRequestTypeDef,
    GetServiceSyncConfigInputRequestTypeDef,
    GetServiceTemplateInputRequestTypeDef,
    GetServiceTemplateVersionInputRequestTypeDef,
    GetTemplateSyncConfigInputRequestTypeDef,
    GetTemplateSyncStatusInputRequestTypeDef,
    ListComponentOutputsInputListComponentOutputsPaginateTypeDef,
    ListComponentOutputsInputRequestTypeDef,
    OutputTypeDef,
    ListComponentProvisionedResourcesInputListComponentProvisionedResourcesPaginateTypeDef,
    ListComponentProvisionedResourcesInputRequestTypeDef,
    ProvisionedResourceTypeDef,
    ListComponentsInputListComponentsPaginateTypeDef,
    ListComponentsInputRequestTypeDef,
    ListEnvironmentAccountConnectionsInputListEnvironmentAccountConnectionsPaginateTypeDef,
    ListEnvironmentAccountConnectionsInputRequestTypeDef,
    ListEnvironmentOutputsInputListEnvironmentOutputsPaginateTypeDef,
    ListEnvironmentOutputsInputRequestTypeDef,
    ListEnvironmentProvisionedResourcesInputListEnvironmentProvisionedResourcesPaginateTypeDef,
    ListEnvironmentProvisionedResourcesInputRequestTypeDef,
    ListEnvironmentTemplateVersionsInputListEnvironmentTemplateVersionsPaginateTypeDef,
    ListEnvironmentTemplateVersionsInputRequestTypeDef,
    ListEnvironmentTemplatesInputListEnvironmentTemplatesPaginateTypeDef,
    ListEnvironmentTemplatesInputRequestTypeDef,
    ListRepositoriesInputListRepositoriesPaginateTypeDef,
    ListRepositoriesInputRequestTypeDef,
    RepositorySummaryTypeDef,
    ListRepositorySyncDefinitionsInputListRepositorySyncDefinitionsPaginateTypeDef,
    ListRepositorySyncDefinitionsInputRequestTypeDef,
    RepositorySyncDefinitionTypeDef,
    ListServiceInstanceOutputsInputListServiceInstanceOutputsPaginateTypeDef,
    ListServiceInstanceOutputsInputRequestTypeDef,
    ListServiceInstanceProvisionedResourcesInputListServiceInstanceProvisionedResourcesPaginateTypeDef,
    ListServiceInstanceProvisionedResourcesInputRequestTypeDef,
    ListServiceInstancesFilterTypeDef,
    ServiceInstanceSummaryTypeDef,
    ListServicePipelineOutputsInputListServicePipelineOutputsPaginateTypeDef,
    ListServicePipelineOutputsInputRequestTypeDef,
    ListServicePipelineProvisionedResourcesInputListServicePipelineProvisionedResourcesPaginateTypeDef,
    ListServicePipelineProvisionedResourcesInputRequestTypeDef,
    ListServiceTemplateVersionsInputListServiceTemplateVersionsPaginateTypeDef,
    ListServiceTemplateVersionsInputRequestTypeDef,
    ServiceTemplateVersionSummaryTypeDef,
    ListServiceTemplatesInputListServiceTemplatesPaginateTypeDef,
    ListServiceTemplatesInputRequestTypeDef,
    ServiceTemplateSummaryTypeDef,
    ListServicesInputListServicesPaginateTypeDef,
    ListServicesInputRequestTypeDef,
    ServiceSummaryTypeDef,
    ListTagsForResourceInputListTagsForResourcePaginateTypeDef,
    ListTagsForResourceInputRequestTypeDef,
    PaginatorConfigTypeDef,
    RejectEnvironmentAccountConnectionInputRequestTypeDef,
    RepositorySyncEventTypeDef,
    ResourceSyncEventTypeDef,
    ResponseMetadataTypeDef,
    S3ObjectSourceTypeDef,
    SyncBlockerContextTypeDef,
    UntagResourceInputRequestTypeDef,
    UpdateComponentInputRequestTypeDef,
    UpdateEnvironmentAccountConnectionInputRequestTypeDef,
    UpdateEnvironmentTemplateInputRequestTypeDef,
    UpdateEnvironmentTemplateVersionInputRequestTypeDef,
    UpdateServiceInputRequestTypeDef,
    UpdateServiceInstanceInputRequestTypeDef,
    UpdateServicePipelineInputRequestTypeDef,
    UpdateServiceSyncBlockerInputRequestTypeDef,
    UpdateServiceSyncConfigInputRequestTypeDef,
    UpdateServiceTemplateInputRequestTypeDef,
    UpdateTemplateSyncConfigInputRequestTypeDef,
    AcceptEnvironmentAccountConnectionOutputTypeDef,
    CreateEnvironmentAccountConnectionOutputTypeDef,
    DeleteEnvironmentAccountConnectionOutputTypeDef,
    GetEnvironmentAccountConnectionOutputTypeDef,
    RejectEnvironmentAccountConnectionOutputTypeDef,
    UpdateEnvironmentAccountConnectionOutputTypeDef,
    AccountSettingsTypeDef,
    EnvironmentTypeDef,
    CancelComponentDeploymentOutputTypeDef,
    CreateComponentOutputTypeDef,
    DeleteComponentOutputTypeDef,
    GetComponentOutputTypeDef,
    UpdateComponentOutputTypeDef,
    CancelServiceInstanceDeploymentOutputTypeDef,
    CreateServiceInstanceOutputTypeDef,
    GetServiceInstanceOutputTypeDef,
    UpdateServiceInstanceOutputTypeDef,
    CancelServicePipelineDeploymentOutputTypeDef,
    ServiceTypeDef,
    UpdateServicePipelineOutputTypeDef,
    UpdateServiceTemplateVersionInputRequestTypeDef,
    ServiceTemplateVersionTypeDef,
    ListComponentsOutputTypeDef,
    CountsSummaryTypeDef,
    CreateComponentInputRequestTypeDef,
    CreateEnvironmentAccountConnectionInputRequestTypeDef,
    CreateEnvironmentTemplateInputRequestTypeDef,
    CreateRepositoryInputRequestTypeDef,
    CreateServiceInputRequestTypeDef,
    CreateServiceInstanceInputRequestTypeDef,
    CreateServiceTemplateInputRequestTypeDef,
    ListTagsForResourceOutputTypeDef,
    TagResourceInputRequestTypeDef,
    CreateEnvironmentInputRequestTypeDef,
    UpdateAccountSettingsInputRequestTypeDef,
    UpdateEnvironmentInputRequestTypeDef,
    CreateEnvironmentTemplateOutputTypeDef,
    DeleteEnvironmentTemplateOutputTypeDef,
    GetEnvironmentTemplateOutputTypeDef,
    UpdateEnvironmentTemplateOutputTypeDef,
    CreateEnvironmentTemplateVersionOutputTypeDef,
    DeleteEnvironmentTemplateVersionOutputTypeDef,
    GetEnvironmentTemplateVersionOutputTypeDef,
    UpdateEnvironmentTemplateVersionOutputTypeDef,
    CreateRepositoryOutputTypeDef,
    DeleteRepositoryOutputTypeDef,
    GetRepositoryOutputTypeDef,
    CreateServiceSyncConfigOutputTypeDef,
    DeleteServiceSyncConfigOutputTypeDef,
    GetServiceSyncConfigOutputTypeDef,
    UpdateServiceSyncConfigOutputTypeDef,
    CreateServiceTemplateOutputTypeDef,
    DeleteServiceTemplateOutputTypeDef,
    GetServiceTemplateOutputTypeDef,
    UpdateServiceTemplateOutputTypeDef,
    CreateTemplateSyncConfigOutputTypeDef,
    DeleteTemplateSyncConfigOutputTypeDef,
    GetTemplateSyncConfigOutputTypeDef,
    UpdateTemplateSyncConfigOutputTypeDef,
    ListEnvironmentAccountConnectionsOutputTypeDef,
    ListEnvironmentsOutputTypeDef,
    ListEnvironmentsInputListEnvironmentsPaginateTypeDef,
    ListEnvironmentsInputRequestTypeDef,
    ListEnvironmentTemplatesOutputTypeDef,
    ListEnvironmentTemplateVersionsOutputTypeDef,
    GetComponentInputComponentDeletedWaitTypeDef,
    GetComponentInputComponentDeployedWaitTypeDef,
    GetEnvironmentInputEnvironmentDeployedWaitTypeDef,
    GetEnvironmentTemplateVersionInputEnvironmentTemplateVersionRegisteredWaitTypeDef,
    GetServiceInputServiceCreatedWaitTypeDef,
    GetServiceInputServiceDeletedWaitTypeDef,
    GetServiceInputServicePipelineDeployedWaitTypeDef,
    GetServiceInputServiceUpdatedWaitTypeDef,
    GetServiceInstanceInputServiceInstanceDeployedWaitTypeDef,
    GetServiceTemplateVersionInputServiceTemplateVersionRegisteredWaitTypeDef,
    ListComponentOutputsOutputTypeDef,
    ListEnvironmentOutputsOutputTypeDef,
    ListServiceInstanceOutputsOutputTypeDef,
    ListServicePipelineOutputsOutputTypeDef,
    NotifyResourceDeploymentStatusChangeInputRequestTypeDef,
    ListComponentProvisionedResourcesOutputTypeDef,
    ListEnvironmentProvisionedResourcesOutputTypeDef,
    ListServiceInstanceProvisionedResourcesOutputTypeDef,
    ListServicePipelineProvisionedResourcesOutputTypeDef,
    ListRepositoriesOutputTypeDef,
    ListRepositorySyncDefinitionsOutputTypeDef,
    ListServiceInstancesInputListServiceInstancesPaginateTypeDef,
    ListServiceInstancesInputRequestTypeDef,
    ListServiceInstancesOutputTypeDef,
    ListServiceTemplateVersionsOutputTypeDef,
    ListServiceTemplatesOutputTypeDef,
    ListServicesOutputTypeDef,
    RepositorySyncAttemptTypeDef,
    ResourceSyncAttemptTypeDef,
    TemplateVersionSourceInputTypeDef,
    SyncBlockerTypeDef,
    GetAccountSettingsOutputTypeDef,
    UpdateAccountSettingsOutputTypeDef,
    CancelEnvironmentDeploymentOutputTypeDef,
    CreateEnvironmentOutputTypeDef,
    DeleteEnvironmentOutputTypeDef,
    GetEnvironmentOutputTypeDef,
    UpdateEnvironmentOutputTypeDef,
    CreateServiceOutputTypeDef,
    DeleteServiceOutputTypeDef,
    GetServiceOutputTypeDef,
    UpdateServiceOutputTypeDef,
    CreateServiceTemplateVersionOutputTypeDef,
    DeleteServiceTemplateVersionOutputTypeDef,
    GetServiceTemplateVersionOutputTypeDef,
    UpdateServiceTemplateVersionOutputTypeDef,
    GetResourcesSummaryOutputTypeDef,
    GetRepositorySyncStatusOutputTypeDef,
    GetServiceInstanceSyncStatusOutputTypeDef,
    GetTemplateSyncStatusOutputTypeDef,
    CreateEnvironmentTemplateVersionInputRequestTypeDef,
    CreateServiceTemplateVersionInputRequestTypeDef,
    ServiceSyncBlockerSummaryTypeDef,
    UpdateServiceSyncBlockerOutputTypeDef,
    GetServiceSyncBlockerSummaryOutputTypeDef,
)


def get_structure() -> AcceptEnvironmentAccountConnectionInputRequestTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for `boto3`
updates. It delivers drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type
  annotations extracted from `botocore` schemas.
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore`, `aiobotocore` and `aioboto3`
  libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.resource` calls
- Auto discovery of types for `session.client` and `session.resource` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`mypy-boto3-proton` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[boto3 docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
